@@ -10,4 +10,6 @@
 NULL
 
 ## quiets concerns of R CMD check re: the .'s that appear in pipelines
-if (getRversion() >= "2.15.1") utils::globalVariables(c(".", "label", "link", "localidad"))
\ No newline at end of file
+if (getRversion() >= "2.15.1") utils::globalVariables(
+  c(".", "label", "link", "localidad", "lat", "lon")
+  )
\ No newline at end of file
